@@ -1508,7 +1508,8 @@ sub _handle_diff_provides {
 
 	if (@packages) {
 	    my $best = join('|', sort { $a <=> $b } map { $_->id } @packages);
-	    $urpm->{debug_URPM}("promoting " . join(' ', _ids_to_fullnames($urpm, split('\|', $best))) . " because of conflict above") if $urpm->{debug_URPM};
+	    my @ids = split('\|', $best);
+	    $urpm->{debug_URPM}("promoting " . join(' ', _ids_to_fullnames($urpm, @ids)) . " because of conflict above") if $urpm->{debug_URPM};
 	    push @$properties, { required => $best, promote => $n, psel => $pkg };
 	} else {
 	    #- no package have been found, we may need to remove the package examined unless
@@ -1754,9 +1755,9 @@ identical to _ids_to_names() modulo short name vs full name
 
 #- side-effects: none
 sub _ids_to_fullnames {
-    my $urpm = shift;
+    my ($urpm, @ids) = @_;
 
-    map { scalar $urpm->{depslist}[$_]->fullname } @_;
+    map { scalar $urpm->{depslist}[$_]->fullname } @ids;
 }
 
 #- side-effects: flag_installed, flag_upgrade
@@ -1945,14 +1946,17 @@ sub compute_flags {
 
     #- now search packages which fullname match given regexps
     if (@regex) {
-	my $large_re_s = join("|", map { "(?:$_)" } @regex);
-	my $re = qr/$large_re_s/;
+	eval {
+		my $large_re_s = join("|", map { "(?:$_)" } @regex);
+		my $re = qr/$large_re_s/;
 
-	foreach my $pkg (@{$urpm->{depslist}}) {
-	    if ($pkg->fullname =~ $re) {
-		compute_flag($urpm, $pkg, %options);
-	    }
-	}
+		foreach my $pkg (@{$urpm->{depslist}}) {
+		    if ($pkg->fullname =~ $re) {
+			compute_flag($urpm, $pkg, %options);
+		    }
+		}
+	};
+	$urpm->{debug_URPM}("reg ex problem: " . $@) if $@;
     }
 }
 
@@ -2375,6 +2379,6 @@ Copyright (C) 2002-2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
-Copyright (C) 2011-2013 Mageia
+Copyright (C) 2011-2016 Mageia
 
 =cut
